==> ugene_1.5.2+repack.orig.tar.gz: ugene-1.5.2/src/plugins_3rdparty/hmm3/src/format/uHMMFormat.h <==
/*****************************************************************
* Unipro UGENE - Integrated Bioinformatics Suite
* Copyright (C) 2008,2009 Unipro, Russia (http://ugene.unipro.ru)
* All Rights Reserved
* 
*     This source code is distributed under the terms of the
*     GNU General Public License. See the files COPYING and LICENSE
*     for details.
*****************************************************************/


#ifndef _GB2_HMMER3_HMM_FORMAT_H_
#define _GB2_HMMER3_HMM_FORMAT_H_

#include <QtCore/QByteArray>
#include <QtCore/QString>
#include <QtCore/QStringList>

#include <core_api/core_api.h>
#include <core_api/DocumentModel.h>
#include <core_api/IOAdapter.h>

namespace GB2 {

class UHMMFormat : public DocumentFormat {
    Q_OBJECT
public:
    static const DocumentFormatId   UHHMER_FORMAT_ID;
    static const QString            WRITE_LOCK_REASON;
    static const QString            WRITE_FAILED;
    
public:
    UHMMFormat( QObject* obj );
    
    virtual DocumentFormatId getFormatId() const;
    
    virtual const QString& getFormatName() const;
    
    virtual QStringList getSupportedDocumentFileExtensions();
    
    virtual Document* loadExistingDocument( IOAdapterFactory* io, const QString& url, TaskStateInfo& ti, const QVariantMap& hints);
    virtual Document* loadExistingDocument( IOAdapter* io, TaskStateInfo& ti, const QVariantMap& formatSettings );
    
    virtual void storeDocument( Document* d, TaskStateInfo& ti, IOAdapterFactory* io = NULL, const QString& newDocURL = QString::null );
    virtual void storeDocument( Document* d, TaskStateInfo& ts, IOAdapter* io );
    
    virtual bool isDataFormatSupported( const char* data, int size ) const;
    
    virtual bool isObjectOpSupported( const Document* d , DocumentFormat::DocObjectOp op, GObjectType t ) const;
    
    virtual bool checkConstraints( const DocumentFormatConstraints& c ) const;
    
    struct UHMMWriteException {
        QString what;
        UHMMWriteException( const QString& msg ) : what( msg ) {}
    }; // UHMMWriteException
    
private:
    QString formatName;
    
}; // UHMMFormat

} // GB2

#endif // _GB2_HMMER3_HMM_FORMAT_H_

==> ugene_1.7.1+repack.orig.tar.gz: ugene-1.7.1/src/plugins_3rdparty/hmm3/src/format/uHMMFormat.h <==
/*****************************************************************
* Unipro UGENE - Integrated Bioinformatics Suite
* Copyright (C) 2008,2009 Unipro, Russia (http://ugene.unipro.ru)
* All Rights Reserved
* 
*     This source code is distributed under the terms of the
*     GNU General Public License. See the files COPYING and LICENSE
*     for details.
*****************************************************************/


#ifndef _GB2_HMMER3_HMM_FORMAT_H_
#define _GB2_HMMER3_HMM_FORMAT_H_

#include <QtCore/QByteArray>
#include <QtCore/QString>
#include <QtCore/QStringList>

#include <core_api/core_api.h>
#include <core_api/DocumentModel.h>
#include <core_api/IOAdapter.h>

namespace GB2 {

class UHMMFormat : public DocumentFormat {
    Q_OBJECT
public:
    static const DocumentFormatId   UHHMER_FORMAT_ID;
    static const QString            WRITE_LOCK_REASON;
    static const QString            WRITE_FAILED;
    
public:
    UHMMFormat( QObject* obj );
    
    virtual DocumentFormatId getFormatId() const;
    
    virtual const QString& getFormatName() const;
    
    
    virtual Document* loadDocument( IOAdapter* io, TaskStateInfo& ti, const QVariantMap& formatSettings, DocumentLoadMode mode = DocumentLoadMode_Whole );
    
    virtual void storeDocument( Document* d, TaskStateInfo& ts, IOAdapter* io );
    
    virtual bool checkRawData( const QByteArray& data) const;
    
    struct UHMMWriteException {
        QString what;
        UHMMWriteException( const QString& msg ) : what( msg ) {}
    }; // UHMMWriteException
    
private:
    QString formatName;
    
}; // UHMMFormat

} // GB2

#endif // _GB2_HMMER3_HMM_FORMAT_H_
